@@ -103,9 +103,9 @@ error:
 /**
  * gsf_input_stdio_new:
  * @filename: in utf8.
- * @err: optionally NULL.
+ * @err: (allow-none): place to store a #GError if anything goes wrong
  *
- * Returns: a new file or NULL.
+ * Returns: a new file or %NULL.
  **/
 /* coverity[ -tainted_string_sink_content : arg-0 ] */
 GsfInput *
@@ -148,6 +148,23 @@ gsf_input_stdio_new (char const *filename, GError **err)
 	input->keep_open = FALSE;
 	gsf_input_set_size (GSF_INPUT (input), size);
 	gsf_input_set_name_from_filename (GSF_INPUT (input), filename);
+	if (st.st_mtime != (time_t)-1) {
+		GDateTime *modtime;
+		GTimeVal tv;
+
+		tv.tv_sec = st.st_mtime;
+#if defined (HAVE_STRUCT_STAT_ST_MTIMENSEC)
+		tv.tv_usec = st.st_mtimensec / 1000;
+#elif defined (HAVE_STRUCT_STAT_ST_MTIM_TV_NSEC)
+		tv.tv_usec =  st.st_mtim.tv_nsec / 1000;
+#else
+		tv.tv_usec = 0;
+#endif
+
+		modtime = g_date_time_new_from_timeval_utc (&tv);
+		gsf_input_set_modtime (GSF_INPUT (input), modtime);
+		g_date_time_unref (modtime);
+	}
 
 	return GSF_INPUT (input);
 }
@@ -155,13 +172,13 @@ gsf_input_stdio_new (char const *filename, GError **err)
 /**
  * gsf_input_stdio_new_FILE:
  * @filename: The filename corresponding to @file.
- * @file: an existing stdio <type>FILE</type> *
+ * @file: (transfer full): an existing stdio <type>FILE</type> *
  * @keep_open: Should @file be closed when the wrapper is closed
  *
  * Assumes ownership of @file when succeeding.  If @keep_open is true,
- * ownership reverts to caller when the GsfObject is closed.
+ * ownership reverts to caller when the #GsfInput is closed.
  *
- * Returns: a new GsfInput wrapper for @file.  Note that if the file is not
+ * Returns: a new #GsfInput wrapper for @file.  Note that if the file is not
  * 	seekable, this function will make a local copy of the entire file.
  **/
 GsfInput *
@@ -319,4 +336,3 @@ gsf_input_stdio_class_init (GObjectClass *gobject_class)
 GSF_CLASS (GsfInputStdio, gsf_input_stdio,
 	   gsf_input_stdio_class_init, gsf_input_stdio_init,
 	   GSF_INPUT_TYPE)
-
